# This program is free software: you can redistribute it and/or modify it under the
# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the Apache License for more details.
#
# You should have received a copy of the Apache License along with this program.
# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.

"""Metadata for CmdKit package."""


__pkgname__   = 'cmdkit'
__version__   = '2.0.1'
__authors__   = 'Geoffrey Lentner'
__contact__   = '<glentner@gmail.com>'
__license__   = 'Apache License'
__copyright__ = 'Copyright (c) Geoffrey Lentner 2019. All Rights Reserved.'
__description__ = 'A command-line utility toolkit.'
